@@ -4,7 +4,7 @@ package App::opan;
 
 use strictures 2;
 
-our $VERSION = '0.001003';
+our $VERSION = '0.002000';
 
 use Dist::Metadata;
 use File::Open qw(fopen);
@@ -85,6 +85,8 @@ sub write_packages_file {
   my $fh = fopen $file, 'w';
   print $fh packages_header(scalar @$entries);
   local *_ = sub {
+    # mirroring 'sub rewrite02 {' in lib/PAUSE/mldistwatch.pm
+    # see http://github.com/andk/pause for the whole thing
     my ($one, $two) = (30, 8);
     if (length($_[0]) > $one) {
       $one += 8 - length($_[1]);
@@ -232,6 +234,7 @@ sub run_with_server {
   my $pid = fork();
   die "fork() fork()ed up: $!" unless defined $pid;
   unless ($pid) {
+    $ENV{OPAN_AUTOPIN} = 1 if $pan eq 'autopin';
     $app->start(daemon => -l => $url);
     exit(0);
   }
@@ -600,7 +603,9 @@ Virtual PAN with no presence on disk.
 Identical to nopin, but fetching a dist from upstream does an implict L</pin>.
 
 Since this can modify your opan config, it's only enabled if the environment
-variable C<OPAN_AUTOPIN> is set to a true value.
+variable C<OPAN_AUTOPIN> is set to a true value (calling the L</cpanm> or
+L</carton> commands with C<--autopin> sets this for you, because you already
+specified you wanted that).
 
 =head1 AUTHOR
 
